package com.mob.adsdk.reactlibrary;

import android.app.Activity;
import android.app.Application;
import android.content.Intent;
import android.os.Bundle;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.BaseActivityEventListener;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.modules.core.DeviceEventManagerModule;
import com.mob.adsdk.AdConfig;
import com.mob.adsdk.AdSdk;
import com.mob.adsdk.reactlibrary.util.DensityUtils;
import com.mob.adsdk.reactlibrary.view.SplashActivity;

public class AdModule extends ReactContextBaseJavaModule {

    private static final int REQUEST_CODE_SPLASH = 1000;

    private final ReactApplicationContext reactContext;
    private Callback mSplashCallback;

    public AdModule(ReactApplicationContext reactContext) {
        super(reactContext);
        this.reactContext = reactContext;

        reactContext.addActivityEventListener(new BaseActivityEventListener() {
            @Override
            public void onActivityResult(Activity activity, int requestCode, int resultCode, Intent data) {
                if (REQUEST_CODE_SPLASH == requestCode) {
                    if (null != mSplashCallback) {
                        WritableMap result = Arguments.createMap();
                        String id = data.getStringExtra("id");
                        int code = data.getIntExtra("code", 0);
                        result.putString("id", id);
                        if (0 == code) {
                            result.putString("event", "onAdDismiss");
                        } else {
                            result.putString("event", "onError");
                            result.putInt("code", code);
                            result.putString("message", data.getStringExtra("message"));
                        }
                        mSplashCallback.invoke(result);
                        mSplashCallback = null;
                    }
                }
            }
        });
    }

    @Override
    public String getName() {
        return "AdSdk";
    }

    @ReactMethod
    public void init(final String appId, final String userId, final boolean multiProcess, final boolean debug, final boolean test) {
        reactContext.runOnUiQueueThread(new Runnable() {
            @Override
            public void run() {
                AdSdk.getInstance().init(reactContext,
                        new AdConfig.Builder()
                                .appId(appId)
                                .userId(userId)
                                .multiProcess(multiProcess)
                                .debug(debug)
                                .test(test)
                                .build(),
                        null);
            }
        });
    }

    @ReactMethod
    public void setUserId(String userId) {
        AdSdk.getInstance().setUserId(userId);
    }

    @ReactMethod
    public void setMinSplashInterval(final int minSplashInterval) {
        Application application = reactContext.getCurrentActivity().getApplication();
        application.registerActivityLifecycleCallbacks(new Application.ActivityLifecycleCallbacks() {
            private int activityCount = 1;
            private long leaveTime = 0;

            @Override
            public void onActivityCreated(Activity activity, Bundle savedInstanceState) {
            }

            @Override
            public void onActivityStarted(Activity activity) {
                if (0 == activityCount++) {
                    // App 回到前台
                    if (System.currentTimeMillis() - leaveTime >= minSplashInterval) {
                        if (!(activity instanceof SplashActivity)) {
                            Intent intent = new Intent(activity, SplashActivity.class);
                            intent.addFlags(Intent.FLAG_ACTIVITY_NO_ANIMATION); // 无动画
                            activity.startActivity(intent);
                        }
                    }
                }
            }

            @Override
            public void onActivityResumed(Activity activity) {
            }

            @Override
            public void onActivityPaused(Activity activity) {
            }

            @Override
            public void onActivityStopped(Activity activity) {
                if (0 == --activityCount) {
                    // App 切到后台
                    leaveTime = System.currentTimeMillis();
                }
            }

            @Override
            public void onActivitySaveInstanceState(Activity activity, Bundle outState) {
            }

            @Override
            public void onActivityDestroyed(Activity activity) {
            }
        });
    }

    @ReactMethod
    public void showSplashAd(Callback callback) {
        Activity activity = reactContext.getCurrentActivity();
        Intent intent = new Intent(activity, SplashActivity.class);
        intent.addFlags(Intent.FLAG_ACTIVITY_NO_ANIMATION);
        activity.startActivityForResult(intent, REQUEST_CODE_SPLASH);
        mSplashCallback = callback;
    }

    @ReactMethod
    public void showRewardVideoAd(final String unitId, final int eventId) {
        reactContext.runOnUiQueueThread(new Runnable() {
            @Override
            public void run() {
                AdSdk.getInstance().loadRewardVideoAd(getCurrentActivity(), unitId, false,
                        new AdSdk.RewardVideoAdListener() {
                            @Override
                            public void onAdLoad(String id) {
                                WritableMap result = Arguments.createMap();
                                result.putInt("eventId", eventId);
                                result.putString("id", id);
                                result.putString("event", "onAdLoad");
                                emitAdEvent(result);
                            }

                            @Override
                            public void onVideoCached(String id) {
                                WritableMap result = Arguments.createMap();
                                result.putInt("eventId", eventId);
                                result.putString("id", id);
                                result.putString("event", "onVideoCached");
                                emitAdEvent(result);
                            }

                            @Override
                            public void onAdShow(String id) {
                                WritableMap result = Arguments.createMap();
                                result.putInt("eventId", eventId);
                                result.putString("id", id);
                                result.putString("event", "onAdShow");
                                emitAdEvent(result);
                            }

                            @Override
                            public void onReward(String id) {
                                WritableMap result = Arguments.createMap();
                                result.putInt("eventId", eventId);
                                result.putString("id", id);
                                result.putString("event", "onReward");
                                emitAdEvent(result);
                            }

                            @Override
                            public void onAdClick(String id) {
                                WritableMap result = Arguments.createMap();
                                result.putInt("eventId", eventId);
                                result.putString("id", id);
                                result.putString("event", "onAdClick");
                                emitAdEvent(result);
                            }

                            @Override
                            public void onVideoComplete(String id) {
                                WritableMap result = Arguments.createMap();
                                result.putInt("eventId", eventId);
                                result.putString("id", id);
                                result.putString("event", "onVideoComplete");
                                emitAdEvent(result);
                            }

                            @Override
                            public void onAdClose(String id) {
                                WritableMap result = Arguments.createMap();
                                result.putInt("eventId", eventId);
                                result.putString("id", id);
                                result.putString("event", "onAdClose");
                                result.putBoolean("end", true);
                                emitAdEvent(result);
                            }

                            @Override
                            public void onError(String id, int code, String message) {
                                WritableMap result = Arguments.createMap();
                                result.putInt("eventId", eventId);
                                result.putString("id", id);
                                result.putString("event", "onError");
                                result.putInt("code", code);
                                result.putString("message", message);
                                result.putBoolean("end", true);
                                emitAdEvent(result);
                            }
                        });
            }
        });
    }

    @ReactMethod
    public void showInterstitialAd(final String unitId, final int eventId) {
        reactContext.runOnUiQueueThread(new Runnable() {
            @Override
            public void run() {
                float screenWidth = DensityUtils.getScreenWidth(reactContext);
                float padding = 50;
                float width = DensityUtils.px2dip(reactContext, screenWidth) - padding * 2;

                AdSdk.getInstance().loadInterstitialAd(getCurrentActivity(), unitId, width, new AdSdk.InterstitialAdListener() {
                    @Override
                    public void onAdLoad(String id) {
                        WritableMap result = Arguments.createMap();
                        result.putInt("eventId", eventId);
                        result.putString("id", id);
                        result.putString("event", "onAdLoad");
                        emitAdEvent(result);
                    }

                    @Override
                    public void onAdShow(String id) {
                        WritableMap result = Arguments.createMap();
                        result.putInt("eventId", eventId);
                        result.putString("id", id);
                        result.putString("event", "onAdShow");
                        emitAdEvent(result);
                    }

                    @Override
                    public void onAdClose(String id) {
                        WritableMap result = Arguments.createMap();
                        result.putInt("eventId", eventId);
                        result.putString("id", id);
                        result.putString("event", "onAdClose");
                        result.putBoolean("end", true);
                        emitAdEvent(result);
                    }

                    @Override
                    public void onAdClick(String id) {
                        WritableMap result = Arguments.createMap();
                        result.putInt("eventId", eventId);
                        result.putString("id", id);
                        result.putString("event", "onAdClick");
                        emitAdEvent(result);
                    }

                    @Override
                    public void onError(String id, int code, String message) {
                        WritableMap result = Arguments.createMap();
                        result.putInt("eventId", eventId);
                        result.putString("id", id);
                        result.putString("event", "onError");
                        result.putInt("code", code);
                        result.putString("message", message);
                        result.putBoolean("end", true);
                        emitAdEvent(result);
                    }
                });
            }
        });
    }

    private void emitAdEvent(WritableMap data) {
        reactContext.getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter.class).emit("onAdEvent", data);
    }
}
