package com.mob.adsdk.reactlibrary.uimanager;

import android.app.Activity;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.mob.adsdk.AdSdk;
import com.mob.adsdk.reactlibrary.view.ContainerView;

public class BannerAdViewManager extends BaseAdViewManager {

    private AdSdk.BannerAd mBannerAd;

    @Override
    public String getName() {
        return "BannerAdView";
    }

    @Override
    public void onDropViewInstance(ContainerView view) {
        if (null != mBannerAd) {
            mBannerAd.destroy();
            mBannerAd = null;
        }
    }

    @ReactProp(name = "src")
    public void setSrc(final ContainerView view, ReadableMap src) {
        if (null == mBannerAd) {
            String unitId = src.getString("unitId");
            int width = src.getInt("width");
            int height = src.getInt("height");
            Activity activity = ((ReactContext) view.getContext()).getCurrentActivity();
            AdSdk.getInstance().loadBannerAd(activity, unitId, view, width, height,
                    new AdSdk.BannerAdListener() {
                        @Override
                        public void onAdLoad(String id, AdSdk.BannerAd ad) {
                            WritableMap result = Arguments.createMap();
                            result.putString("id", id);
                            result.putString("event", "onAdLoad");
                            receiveEvent(view, result);

                            // 设置刷新频率，为0或30~120之间的整数，单位秒，0表示不自动轮播，默认30秒
                            ad.setRefreshInterval(30);
                            mBannerAd = ad;
                        }

                        @Override
                        public void onAdShow(String id) {
                            WritableMap result = Arguments.createMap();
                            result.putString("id", id);
                            result.putString("event", "onAdShow");
                            receiveEvent(view, result);
                        }

                        @Override
                        public void onAdClose(String id) {
                            WritableMap result = Arguments.createMap();
                            result.putString("id", id);
                            result.putString("event", "onAdClose");
                            receiveEvent(view, result);
                        }

                        @Override
                        public void onAdClick(String id) {
                            WritableMap result = Arguments.createMap();
                            result.putString("id", id);
                            result.putString("event", "onAdClick");
                            receiveEvent(view, result);
                        }

                        @Override
                        public void onError(String id, int code, String message) {
                            WritableMap result = Arguments.createMap();
                            result.putString("id", id);
                            result.putString("event", "onError");
                            result.putInt("code", code);
                            result.putString("message", message);
                            receiveEvent(view, result);
                        }
                    });
        }
    }
}
