package com.mob.adsdk.reactlibrary.uimanager;

import android.view.ViewTreeObserver;

import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentActivity;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.mob.adsdk.AdSdk;
import com.mob.adsdk.reactlibrary.view.ContainerView;

public class DrawFeedViewManager extends BaseAdViewManager {

    private Fragment mDrawVideoFragment;

    @Override
    public String getName() {
        return "DrawFeedView";
    }

    @Override
    public void onDropViewInstance(ContainerView view) {
        mDrawVideoFragment = null;
    }

    @ReactProp(name = "src")
    public void setSrc(final ContainerView view, ReadableMap src) {
        if (null == mDrawVideoFragment) {
            String unitId = src.getString("unitId");
            final FragmentActivity activity = (FragmentActivity) ((ReactContext) view.getContext()).getCurrentActivity();
            mDrawVideoFragment = AdSdk.getInstance().getDrawVideoFragment(activity, unitId, new AdSdk.DrawVideoListener() {

                @Override
                public void onVideoShow(String id, int videoType) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putInt("videoType", videoType);
                    result.putString("event", "onVideoShow");
                    receiveEvent(view, result);
                }

                @Override
                public void onVideoStart(String id, int videoType) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putInt("videoType", videoType);
                    result.putString("event", "onVideoStart");
                    receiveEvent(view, result);
                }

                @Override
                public void onVideoPause(String id, int videoType) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putInt("videoType", videoType);
                    result.putString("event", "onVideoPause");
                    receiveEvent(view, result);
                }

                @Override
                public void onVideoResume(String id, int videoType) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putInt("videoType", videoType);
                    result.putString("event", "onVideoResume");
                    receiveEvent(view, result);
                }

                @Override
                public void onVideoComplete(String id, int videoType) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putInt("videoType", videoType);
                    result.putString("event", "onVideoComplete");
                    receiveEvent(view, result);
                }

                @Override
                public void onVideoError(String id, int videoType, int code) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putInt("videoType", videoType);
                    result.putString("event", "onVideoError");
                    result.putInt("code", code);
                    receiveEvent(view, result);
                }

                @Override
                public void onError(String id, int code, String message) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onError");
                    result.putInt("code", code);
                    result.putString("message", message);
                    receiveEvent(view, result);
                }
            });

            view.getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() {
                @Override
                public void onGlobalLayout() {
                    if (null != view.getParent()) {
                        view.getViewTreeObserver().removeOnGlobalLayoutListener(this);

                        activity.getSupportFragmentManager()
                                .beginTransaction()
                                .replace(view.getId(), mDrawVideoFragment)
                                .commitNowAllowingStateLoss();
                    }
                }
            });
        }
    }
}
