package com.mob.adsdk.reactlibrary.uimanager;

import android.app.Activity;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.mob.adsdk.AdSdk;
import com.mob.adsdk.reactlibrary.view.ContainerView;

import java.util.List;

public class DrawVideoAdViewManager extends BaseAdViewManager {

    private AdSdk.DrawVideoAd mDrawVideoAd;

    @Override
    public String getName() {
        return "DrawVideoAdView";
    }

    @Override
    public void onDropViewInstance(ContainerView view) {
        if (null != mDrawVideoAd) {
            mDrawVideoAd.destroy();
            mDrawVideoAd = null;
        }
    }

    @ReactProp(name = "src")
    public void setSrc(final ContainerView view, ReadableMap src) {
        if (null == mDrawVideoAd) {
            String unitId = src.getString("unitId");
            Activity activity = ((ReactContext) view.getContext()).getCurrentActivity();
            AdSdk.getInstance().loadDrawVideoAd(activity, unitId, 1, new AdSdk.DrawVideoAdListener() {
                @Override
                public void onAdLoad(List<AdSdk.DrawVideoAd> ads) {
                    if (ads == null || ads.size() == 0) {
                        return;
                    }
                    final AdSdk.DrawVideoAd drawVideoAd = ads.get(0);
                    drawVideoAd.render(view);
                    mDrawVideoAd = drawVideoAd;

                    WritableMap result = Arguments.createMap();
                    result.putString("id", drawVideoAd.getId());
                    result.putString("event", "onAdLoad");
                    receiveEvent(view, result);
                }

                @Override
                public void onAdShow(String id) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onAdShow");
                    receiveEvent(view, result);
                }

                @Override
                public void onAdClick(String id) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onAdClick");
                    receiveEvent(view, result);
                }

                @Override
                public void onVideoStart(String id) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onVideoStart");
                    receiveEvent(view, result);
                }

                @Override
                public void onVideoPause(String id) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onVideoPause");
                    receiveEvent(view, result);
                }

                @Override
                public void onVideoResume(String id) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onVideoResume");
                    receiveEvent(view, result);
                }

                @Override
                public void onVideoComplete(String id) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onVideoComplete");
                    receiveEvent(view, result);
                }

                @Override
                public void onError(String id, int code, String message) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onError");
                    result.putInt("code", code);
                    result.putString("message", message);
                    receiveEvent(view, result);
                }
            });
        }
    }
}
