package com.mob.adsdk.reactlibrary.uimanager;

import android.app.Activity;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.mob.adsdk.AdSdk;
import com.mob.adsdk.reactlibrary.view.ContainerView;

public class DrawVideoEntryViewManager extends BaseAdViewManager {

    private AdSdk.DrawVideoEntry mDrawVideoEntry;

    @Override
    public String getName() {
        return "DrawVideoEntryView";
    }

    @Override
    public void onDropViewInstance(ContainerView view) {
        mDrawVideoEntry = null;
    }

    @ReactProp(name = "src")
    public void setSrc(final ContainerView view, ReadableMap src) {
        if (null == mDrawVideoEntry) {
            String unitId = src.getString("unitId");
            Activity activity = ((ReactContext) view.getContext()).getCurrentActivity();
            AdSdk.getInstance().loadDrawVideoEntry(activity, unitId,
                    new AdSdk.DrawVideoEntryListener() {
                        @Override
                        public void onLoad(String id, AdSdk.DrawVideoEntry entry) {
                            entry.render(view);
                            mDrawVideoEntry = entry;

                            WritableMap result = Arguments.createMap();
                            result.putString("id", entry.getId());
                            result.putString("event", "onLoad");
                            receiveEvent(view, result);
                        }

                        @Override
                        public void onClick(String id, int pos) {
                            WritableMap result = Arguments.createMap();
                            result.putString("id", id);
                            result.putInt("pos", pos);
                            result.putString("event", "onClick");
                            receiveEvent(view, result);
                        }

                        @Override
                        public void onError(String id, int code, String message) {
                            WritableMap result = Arguments.createMap();
                            result.putString("id", id);
                            result.putString("event", "onError");
                            result.putInt("code", code);
                            result.putString("message", message);
                            receiveEvent(view, result);
                        }
                    });
        }
    }
}
