package com.mob.adsdk.reactlibrary.uimanager;

import android.app.Activity;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.mob.adsdk.AdSdk;
import com.mob.adsdk.reactlibrary.view.ContainerView;

import java.util.List;

public class NativeAdViewManager extends BaseAdViewManager {

    private AdSdk.NativeExpressAd mNativeAd;

    @Override
    public String getName() {
        return "NativeAdView";
    }

    @Override
    public void onDropViewInstance(ContainerView view) {
        if (null != mNativeAd) {
            mNativeAd.destroy();
            mNativeAd = null;
        }
    }

    @ReactProp(name = "src")
    public void setSrc(final ContainerView view, ReadableMap src) {
        if (null == mNativeAd) {
            String unitId = src.getString("unitId");
            int width = src.getInt("width");
            Activity activity = ((ReactContext) view.getContext()).getCurrentActivity();
            AdSdk.getInstance().loadNativeExpressAd(activity, unitId, width, 1, new AdSdk.NativeExpressAdListener() {
                @Override
                public void onAdLoad(List<AdSdk.NativeExpressAd> ads) {
                    if (ads == null || ads.size() == 0) {
                        return;
                    }
                    final AdSdk.NativeExpressAd nativeExpressAd = ads.get(0);
                    nativeExpressAd.render(view);
                    mNativeAd = nativeExpressAd;

                    WritableMap result = Arguments.createMap();
                    result.putString("id", nativeExpressAd.getId());
                    result.putString("event", "onAdLoad");
                    receiveEvent(view, result);
                }

                @Override
                public void onAdShow(String id) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onAdShow");
                    receiveEvent(view, result);
                }

                @Override
                public void onAdClose(String id) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onAdClose");
                    receiveEvent(view, result);
                }

                @Override
                public void onAdClick(String id) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onAdClick");
                    receiveEvent(view, result);
                }

                @Override
                public void onError(String id, int code, String message) {
                    WritableMap result = Arguments.createMap();
                    result.putString("id", id);
                    result.putString("event", "onError");
                    result.putInt("code", code);
                    result.putString("message", message);
                    receiveEvent(view, result);
                }
            });
        }
    }
}
