//
//  MobADBannerView.m
//  react-native-mobad
//
//  Created by hoc on 2020/12/2.
//

#import "MobADBannerView.h"
#import <MobADSDK/MobADSDKApi.h>
#import "ADUniTool.h"

@interface MobADBannerView ()<MADBannerAdCallbackDelegate>
{
    id<MADBannerAdManagerProtocol> _bannerAd;
}

@end

@implementation MobADBannerView

- (void)setSrc:(NSDictionary *)src {
    _src = src;
    
    if (!_bannerAd) {
        _bannerAd = [MobADSDKApi bannerAdManager];
    }
    
    NSString *unitId = src[@"unitId"];
    NSNumber *width = src[@"width"];
    NSNumber *height = src[@"height"];
    
    CGRect frame = CGRectMake(0, 0, [width floatValue], [height floatValue]);
    [_bannerAd loadBannerAdWithFrame:frame viewController:[ADUniTool findCurrentShowingViewController] delegate:self interval:30 group:unitId];
}

- (void)ad_bannerAdView:(UIView<MADBannerAdViewProtocol> *)adView callbackWithEvent:(MADBannerAdCallbackEvent)event error:(NSError *)error andInfo:(NSDictionary *)info {
    NSLog(@"ad_bannerAdView = %@, %@ , %@" , [MobADBannerView eventStringForEvent:event], error, info);
    if (event == MADBannerAdCallbackEventAdLoadSuccess) {
        if (!adView.superview) {
            [self addSubview:adView];
            adView.backgroundColor = [UIColor clearColor];
            adView.frame = self.bounds;
        }
    } else if (event == MADBannerAdCallbackEventAdDidClose) {
        [_bannerAd removeBannerAd:adView];
        [self removeFromSuperview];
    }
    
    NSMutableDictionary *para = [[NSMutableDictionary alloc] init];
    [para setValue:info[@"id"] ?: [NSNull null] forKey:@"id"];
    [para setValue:[MobADBannerView eventStringForEvent:event] forKey:@"event"];
    if (error) {
        [para setValue:error.userInfo[NSLocalizedDescriptionKey] ?: [NSNull null] forKey:@"message"];
        [para setValue:@(error.code) ?: [NSNull null] forKey:@"code"];
    }
    if (self.onEvent) {
        self.onEvent(para);
    }
}

+ (NSString *)eventStringForEvent:(MADBannerAdCallbackEvent)event {
    switch (event) {
        case MADBannerAdCallbackEventAdLoadSuccess:
            return @"onAdLoad";
            break;
        case MADBannerAdCallbackEventAdLoadError:
            return @"onAdError";
            break;
        case MADBannerAdCallbackEventAdWillVisible:
            return @"onAdShow";
            break;
        case MADBannerAdCallbackEventAdDidClick:
            return @"onAdClick";
            break;
        default:
            return @"onAdClose";
            break;
    }
}

@end
