//
//  MobAdNativeView.m
//  react-native-mobad
//
//  Created by hoc on 2020/12/2.
//

#import "MobAdNativeView.h"
#import <MobADSDK/MobADSDKApi.h>
#import "ADUniTool.h"

@interface MobAdNativeView ()<MADNativeExpressAdDelegete>
{
    id<MADNativeExpressAdManagerProtocol> _adManager;
}
@property (nonatomic, weak) UIView *nativeView;

@end

@implementation MobAdNativeView

- (void)setSrc:(NSDictionary *)src {
    _src = src;
    
    if (!_adManager) {
        _adManager = [MobADSDKApi nativeExpressAdManager];
    }
    NSString *unitId = src[@"unitId"];
    NSNumber *width = src[@"width"];
    [_adManager loadNativeExpressAdWithCount:1 width:[width floatValue] delegate:self group:unitId];
}

- (void)ad_nativeExpressAdManager:(id<MADNativeExpressAdManagerProtocol>)manager didFinishLoad:(NSArray<id<MADNativeExpressAdProtocol>> *)ads error:(NSError *)error {
    
    if (error) {
        id<MADNativeExpressAdProtocol> ad = ads.firstObject;
        NSDictionary *para = @{@"event":@"onError",
                               @"id": ad.adId ?: [NSNull null],
                               @"code":@(error.code),
                               @"message": error.userInfo[NSLocalizedDescriptionKey] ?:@""};
        if (self.onEvent) {
            self.onEvent(para);
        }
    } else {
        id<MADNativeExpressAdProtocol> ad = ads.firstObject;
        
        NSDictionary *para = @{@"event":@"onAdLoad",
                               @"id":ad.adId ?: [NSNull null]};
        if (self.onEvent) {
            self.onEvent(para);
        }
        
        if (ad) {
            ad.viewController = [ADUniTool findCurrentShowingViewController];
            [ad render];
            [self addSubview:ad.adView];
            self.nativeView = ad.adView;
        }
    }
}

- (void)ad_nativeExpressAdViewRenderSuccess:(id<MADNativeExpressAdProtocol>)ad {
}

- (void)ad_nativeExpressAdViewWillShow:(id<MADNativeExpressAdProtocol>)ad {
    NSDictionary *para = @{@"event":@"onAdShow",
                           @"id":ad.adId ?: [NSNull null]};
    if (self.onEvent) {
        self.onEvent(para);
    }
}

- (void)ad_nativeExpressAdViewClicked:(id<MADNativeExpressAdProtocol>)ad {
    
    if (![ad isKindOfClass:[NSDictionary class]]) {
        NSDictionary *para = @{@"event":@"onAdClick",
                               @"id":ad.adId ?: [NSNull null]};
        if (self.onEvent) {
            self.onEvent(para);
        }
    }
}

- (void)ad_nativeExpressAdViewClosed:(id<MADNativeExpressAdProtocol>)ad reason:(NSString *)reason {
    NSDictionary *para = @{@"event":@"onAdClose",
                           @"id":ad.adId ?: [NSNull null]};
    
    if (self.onEvent) {
        self.onEvent(para);
    }
    
    [self.nativeView removeFromSuperview];
    [self removeFromSuperview];
}

- (void)dealloc {
    NSLog(@"%s", __func__);
    _adManager = nil;
    self.nativeView = nil;
    if (self.onEvent) {
        self.onEvent = nil;
    }
}

@end

