//
//  MobDrawVideoAdView.m
//  react-native-mobad
//
//  Created by hoc on 2020/12/2.
//

#import "MobDrawVideoAdView.h"
#import <MobADSDK/MobADSDKApi.h>
#import "ADUniTool.h"

@protocol MobADDrawVideoAdViewProtocol <NSObject>

@property (nonatomic, strong) NSString *lk_docId;

@end

@interface MobDrawVideoAdView ()<MADExpressDrawVideoAdCallbackDelegate>
{
    id<MADExpressDrawVideoAdManagerProtocol> _drawVideoAdManager;
}

@end

@implementation MobDrawVideoAdView

- (void)setSrc:(NSDictionary *)src {
    _src = src;

    if (!_drawVideoAdManager) {
        _drawVideoAdManager = [MobADSDKApi expressDrawVideoAdManager];
    }
    
    NSString *unitId = src[@"unitId"];
    [_drawVideoAdManager loadVideoAdWithViewController:[ADUniTool findCurrentShowingViewController] delegate:self adCount:1 adSize:CGSizeMake(self.frame.size.width, self.frame.size.height) config:@{@"bottomOffset":@(40)} group:unitId];
}

- (void)ad_drawVideoAdManager:(id<MADExpressDrawVideoAdManagerProtocol>)manager didFinishLoad:(NSArray<id<MADExpressDrawVideoAdProtocol>> *)ads error:(NSError *)error {
    
    NSDictionary *para;
    if (ads.count) {
        id<MADExpressDrawVideoAdProtocol> ad = [ads firstObject];
        [self addSubview:ad.adView];
        [ad render];
        
        id<MobADDrawVideoAdViewProtocol> protocol = ad.adView;
        para = @{@"event":@"onAdLoad",
                 @"id": protocol.lk_docId ?: [NSNull null]};
        
    } else {
        para = @{@"event":@"onError",
                 @"id":[NSNull null],
                 @"code":@(error.code),
                 @"message": error.userInfo[NSLocalizedDescriptionKey] ?: [NSNull null]};
    }
    if (self.onEvent) {
        self.onEvent(para);
    }
}

- (void)ad_drawVideoAdViewWillShow:(NSString *)adId {
    NSDictionary *para = @{@"event":@"onAdShow",
                           @"id": adId ?: [NSNull null]};
    if (self.onEvent) {
        self.onEvent(para);
    }
}

- (void)ad_drawVideoAdViewDidClick:(NSString *)adId {
    NSDictionary *para = @{@"event":@"onAdClick",
                           @"id": adId ?: [NSNull null]};
    if (self.onEvent) {
        self.onEvent(para);
    }
}

- (void)ad_drawVideoAdView:(NSString *)adId stateDidChanged:(MADPlayerPlayState)playerState {
    NSLog(@"draw video ad -> state:%zd", playerState);
    if (playerState == MADPlayerStatePlaying) {
        NSDictionary *para = @{@"event":@"onVideoStart",
                               @"id": adId ?: [NSNull null]};
        if (self.onEvent) {
            self.onEvent(para);
        }
    } else if (playerState == MADPlayerStatePause) {
        NSDictionary *para = @{@"event":@"onVideoPause",
                               @"id": adId ?: [NSNull null]};
        if (self.onEvent) {
            self.onEvent(para);
        }
    }
}

- (void)ad_drawVideoAdPlayerDidPlayFinish:(NSString *)adId error:(NSError *)error {
    NSDictionary *para;
    if (error) {
        para = @{@"event":@"onError",
                 @"id": adId ?: [NSNull null],
                 @"code":@(error.code),
                 @"message": error.userInfo[NSLocalizedDescriptionKey] ?: [NSNull null]};
    } else {
        para = @{@"event":@"onVideoComplete",
                 @"id": adId ?: [NSNull null]};
    }
    if (self.onEvent) {
        self.onEvent(para);
    }
}

@end
