#import "Mobad.h"
#import <MobADSDK/MobADSDKApi.h>
#import "ADUniTool.h"

@interface Mobad ()<MADRewardVideoAdCallbackDelegate, MADSplashAdCallbackDelegate, MADInterstitialAdCallbackDelegate>
{
    id<MADRewardVideoAdManagerProtocol> _rewardVideo;
}
@property (nonatomic, strong) UIView *splashView;
@property (nonatomic, assign) NSInteger rewardID;
@property (nonatomic, assign) NSInteger interstitialID;

@property (nonatomic, assign) BOOL NoRewardCallBack;

@end

@implementation Mobad

RCT_EXPORT_MODULE(AdSdk);

- (dispatch_queue_t)methodQueue
{
  return dispatch_get_main_queue();
}

RCT_EXPORT_METHOD(init:(NSString *)appId userId:(NSString *)userId multiProcess:(BOOL)multiProcess debug:(BOOL)debug test:(BOOL)test) {
    MobADConfigModel *config = [[MobADConfigModel alloc] init];
    
    config.appId = appId;
    if ([userId isKindOfClass:[NSString class]] || [userId isKindOfClass:[NSNumber class]]) {
        MobADConfigModel *config = [MobADSDKApi getConfig];
        config.userId = [NSString stringWithFormat:@"%@", userId];
    }
    [MobADSDKApi setupWithConfig:config];
}

RCT_EXPORT_METHOD(setUserId:(NSString *)userId)
{
    if (userId) {
        if ([userId isKindOfClass:[NSString class]] || [userId isKindOfClass:[NSNumber class]]) {
            MobADConfigModel *config = [MobADSDKApi getConfig];
            config.userId = [NSString stringWithFormat:@"%@", userId];
        }
    } else {
        MobADConfigModel *config = [MobADSDKApi getConfig];
        config.userId = nil;
    }
}

RCT_EXPORT_METHOD(setMinSplashInterval:(NSInteger )interval) {
    NSInteger iInt = interval/1000;
    [ADUniTool sharedTool].splashInterval = iInt;
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(applicationWillEnterForeground) name:UIApplicationWillEnterForegroundNotification object:nil];
}

- (void)applicationWillEnterForeground {
    // 正常的接入一般距离上次开屏间隔指定时间，接入方自行实现
    if (!self.splashView.superview) {
        NSInteger iInt = [ADUniTool sharedTool].splashInterval;
        if (!iInt) {
            iInt = 3;
        }
        if (iInt) {
            self.NoRewardCallBack = YES;
        }
        self.splashView = [MobADSDKApi splashAdViewFromWindow:[UIApplication sharedApplication].keyWindow delegate:self placeHolder:nil customView:nil timeout:iInt isLaunch:NO group:@"s1"];
    }
}

RCT_EXPORT_METHOD(showSplashAd:(RCTResponseSenderBlock)callback) {
    _splashView = [MobADSDKApi splashAdViewFromWindow:[UIApplication sharedApplication].keyWindow delegate:self placeHolder:nil customView:nil timeout:3 isLaunch:YES group:@"s1"];
}

RCT_EXPORT_METHOD(showRewardVideoAd:(NSString *)info eventId:(NSInteger)eventId) {
    self.rewardID = eventId;
    if (!_rewardVideo) {
        _rewardVideo = [MobADSDKApi rewardVideoAdManager];
    }
    if ([ADUniTool isInvalidString:info]) {
        info = @"rv1";
    }
    [_rewardVideo loadRewardVideoWithViewController:[ADUniTool findCurrentShowingViewController] delegate:self timeout:10 group:info];
}

RCT_EXPORT_METHOD(showInterstitialAd:(NSString *)info eventId:(NSInteger)eventId) {
    self.interstitialID = eventId;
    if ([ADUniTool isInvalidString:info]) {
        info = @"i1";
    }
    [MobADSDKApi showInterstitialAdWithViewController:[ADUniTool findCurrentShowingViewController] delegate:self group:info];
}

- (void)ad_splashAdCallbackWithEvent:(MADSplashAdCallbackEvent)event error:(NSError *)error andInfo:(NSDictionary *)info {
    NSMutableDictionary *para = [[NSMutableDictionary alloc] init];
    [para setValue:info[@"id"] ?: [NSNull null] forKey:@"id"];
    if (event == MADSplashAdCallbackEventAdDidClose) {
        [para setValue:@"onAdDismiss" forKey:@"event"];
        
        if (!self.NoRewardCallBack) {
            [self SplashAdCallback:para];
        }
    } else if (event == MADSplashAdCallbackEventAdLoadError) {
        [para setValue:@"onError" forKey:@"event"];
        if (error) {
            [para setValue:error.userInfo[NSLocalizedDescriptionKey] ?: [NSNull null] forKey:@"message"];
            [para setValue:@(error.code) ?: [NSNull null] forKey:@"code"];
        }
        if (!self.NoRewardCallBack) {
            [self SplashAdCallback:para];
        }
    }
}

- (void)ad_rewardVideoCallbackWithEvent:(MADRewardVideoCallbackEvent)event error:(NSError *)error andInfo:(NSDictionary *)info {
    NSMutableDictionary *para = [[NSMutableDictionary alloc] init];
    [para setValue:info[@"id"] ?: [NSNull null] forKey:@"id"];
    [para setValue:[Mobad rewardVideo_eventStringWithEvent:event] forKey:@"event"];
    if (error) {
        [para setValue:error.userInfo[NSLocalizedDescriptionKey] ?: [NSNull null] forKey:@"message"];
        [para setValue:@(error.code) ?: [NSNull null] forKey:@"code"];
    }
    [para setValue:@(self.rewardID) forKey:@"eventId"];
    if (event == MADRewardVideoCallbackEventAdLoadError || event == MADRewardVideoCallbackEventAdDidClose || event == MADRewardVideoCallbackEventAdPlayError) {
        [para setValue:@(YES) forKey:@"end"];
    }
    [self RewardVideoAdCallback:para];
}

- (void)ad_interstitialAdCallbackWithEvent:(MADInterstitialAdCallbackEvent)event error:(NSError *)error andInfo:(NSDictionary *)info {
    NSMutableDictionary *para = [[NSMutableDictionary alloc] init];
    [para setValue:info[@"id"] forKey:@"id"];
    [para setValue:[Mobad intersticial_eventStringWithEvent:event] forKey:@"event"];
    if (error) {
        [para setValue:@(error.code) forKey:@"code"];
        [para setValue:error.userInfo[NSLocalizedDescriptionKey] ?: [NSNull null] forKey:@"message"];
    }
    [para setValue:@(self.interstitialID) forKey:@"eventId"];
    if (event == MADInterstitialAdCallbackEventAdLoadError || event == MADInterstitialAdCallbackEventAdDidClose) {
        [para setValue:@(YES) forKey:@"end"];
    }
    [self InterstitialAdCallback:para];
}

- (NSArray<NSString *> *)supportedEvents {
    return @[@"onAdEvent"];
}

-(void)SplashAdCallback:(NSDictionary *)info
{
    [self sendEventWithName:@"onAdEvent" body:info];
}

-(void)InterstitialAdCallback:(NSDictionary *)info
{
    [self sendEventWithName:@"onAdEvent" body:info];
}

-(void)RewardVideoAdCallback:(NSDictionary *)info
{
    [self sendEventWithName:@"onAdEvent" body:info];
}

+ (NSString *)splash_eventStringWithEvent:(NSInteger)event {
    switch (event) {
        case MADSplashAdCallbackEventAdLoadSuccess:
            //return @"onAdLoad";
            return nil;
            break;
        case MADSplashAdCallbackEventAdWillVisible:
            //return @"onAdShow";
            return nil;
            break;
        case MADSplashAdCallbackEventAdDidClick:
            //return @"onAdClick";
            return nil;
            break;
        case MADSplashAdCallbackEventAdDidClose:
            return @"onAdDismiss";
            break;
        default:
            return @"onError";
            break;
    }
}

+ (NSString *)rewardVideo_eventStringWithEvent:(NSInteger)event {
    switch (event) {
        case MADRewardVideoCallbackEventAdLoadSuccess:
            return @"onAdLoad";
            break;
        case MADRewardVideoCallbackEventAdDidLoadVideo:
            return @"onVideoCached";
            break;
        case MADRewardVideoCallbackEventAdWillVisible:
            return @"onAdShow";
            break;
        case MADRewardVideoCallbackEventAdDidClick:
            return @"onAdClick";
            break;
        case MADRewardVideoCallbackEventAdRewardSuccess:
            return @"onReward";
            break;
        case MADRewardVideoCallbackEventAdPlayFinish:
            return @"onVideoComplete";
            break;
        case MADRewardVideoCallbackEventAdDidClose:
            return @"onAdClose";
            break;
        default:
            return @"onError";
            break;
    }
}

+ (NSString *)intersticial_eventStringWithEvent:(NSInteger)event {
    switch (event) {
        case MADInterstitialAdCallbackEventAdLoadSuccess:
            return @"onAdLoad";
            break;
        case MADInterstitialAdCallbackEventAdWillVisible:
            return @"onAdShow";
            break;
        case MADInterstitialAdCallbackEventAdDidClick:
            return @"onAdClick";
            break;
        case MADInterstitialAdCallbackEventAdDidClose:
            return @"onAdClose";
            break;
        default:
            return @"onError";
            break;
    }
}

@end

