import {NativeModules, NativeEventEmitter} from 'react-native';

const {AdSdk} = NativeModules;

const eventParams = {};
const eventEmitter = new NativeEventEmitter(AdSdk);
eventEmitter.addListener('onAdEvent', (data) => {
  const params = eventParams[data.eventId];
  if (params && params[data.event]) {
    delete data.eventId;
    params[data.event](data);
  }
  if (data.end) {
    delete eventParams[data.eventId];
  }
});

let eventId = 0;

export default {
  init(params) {
    AdSdk.init(
      params.appId,
      params.userId ? params.userId + '' : null,
      params.multiProcess || false,
      params.debug || false,
      params.test || false,
    );
  },
  setUserId(userId) {
    AdSdk.setUserId(userId ? userId + '' : null);
  },
  setMinSplashInterval(minSplashInterval) {
    AdSdk.setMinSplashInterval(minSplashInterval);
  },
  showSplashAd(params) {
    AdSdk.showSplashAd((data) => {
      if (params[data.event]) {
        params[data.event](data);
      }
    });
  },
  showRewardVideoAd(params) {
    eventParams[++eventId] = params;
    AdSdk.showRewardVideoAd(params.unitId, eventId);
  },
  showInterstitialAd(params) {
    eventParams[++eventId] = params;
    AdSdk.showInterstitialAd(params.unitId, eventId);
  },
};
